@@ -1,10 +1,10 @@
-;;; olivetti.el --- Minor mode for a nice writing environment -*- lexical-binding: t; -*-
+;;; olivetti.el --- Minor mode to automatically balance window margins -*- lexical-binding: t; -*-
 
-;; Copyright (c) 2014-2023  Paul W. Rankin
+;; Copyright (c) 2014-2024  Paul W. Rankin
 
-;; Author: Paul W. Rankin <hello@paulwrankin.com>
+;; Author: Paul W. Rankin <rnkn@rnkn.xyz>
 ;; Keywords: wp, text
-;; Version: 2.0.5
+;; Version: 2.0.7
 ;; Package-Requires: ((emacs "24.4"))
 ;; URL: https://github.com/rnkn/olivetti
 
@@ -272,10 +272,10 @@ if it is an integer, and otherwise return WIDTH."
     (setq min-width-pix (* char-width
                            (+ olivetti-minimum-body-width
                               (% olivetti-minimum-body-width 2))))
-    (olivetti-scale-width
      (if (floatp width)
          (floor (max min-width-pix (* window-width-pix (min width 1.0))))
-       (max min-width-pix (min (* width char-width) window-width-pix))))))
+       (olivetti-scale-width
+        (max min-width-pix (min (* width char-width) window-width-pix))))))
 
 (defun olivetti-reset-window (window)
   "Remove Olivetti's parameters and margins from WINDOW."
@@ -482,6 +482,7 @@ body width set with `olivetti-body-width'."
     (remove-hook 'text-scale-mode-hook
                  #'olivetti-set-window t)
     (olivetti-set-buffer-windows)
+    (set-window-margins nil left-margin-width right-margin-width)
     (when olivetti--face-remap
       (face-remap-remove-relative olivetti--face-remap))
     (when olivetti-recall-visual-line-mode-entry-state
